@@ -1,5 +1,6 @@
 /****************************************************************************
- * Copyright (c) 1998-2005,2009 Free Software Foundation, Inc.              *
+ * Copyright 2020 Thomas E. Dickey                                          *
+ * Copyright 1998-2010,2012 Free Software Foundation, Inc.                  *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -36,13 +37,13 @@
  */
 #include "panel.priv.h"
 
-MODULE_ID("$Id: p_above.c,v 1.7 2009/04/11 20:03:06 tom Exp $")
+MODULE_ID("$Id: p_above.c,v 1.10 2020/02/02 23:34:34 tom Exp $")
 
 #if NCURSES_SP_FUNCS
 NCURSES_EXPORT(PANEL *)
 ground_panel(SCREEN * sp)
 {
-  T((T_CALLED("ground_panel(%p)"), sp));
+  T((T_CALLED("ground_panel(%p)"), (void *)sp));
   if (sp)
     {
       struct panelhook *ph = NCURSES_SP_NAME(_nc_panelhook) (sp);
@@ -67,7 +68,7 @@ panel_above(const PANEL * pan)
 {
   PANEL *result;
 
-  T((T_CALLED("panel_above(%p)"), pan));
+  T((T_CALLED("panel_above(%p)"), (const void *)pan));
   if (pan)
     result = pan->above;
   else
