@@ -1,5 +1,6 @@
 /****************************************************************************
- * Copyright (c) 2011-2012,2016 Free Software Foundation, Inc.              *
+ * Copyright 2018,2020 Thomas E. Dickey                                     *
+ * Copyright 2011-2012,2016 Free Software Foundation, Inc.                  *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -26,7 +27,7 @@
  * authorization.                                                           *
  ****************************************************************************/
 /*
- * $Id: color_name.h,v 1.5 2016/09/04 20:11:36 tom Exp $
+ * $Id: color_name.h,v 1.8 2020/06/20 18:58:20 tom Exp $
  */
 
 #ifndef __COLORNAME_H
@@ -79,7 +80,7 @@ color_code(const char *color)
     }
     return result;
 }
-#endif /* NEED_COLOR_NAME */
+#endif /* NEED_COLOR_CODE */
 
 #ifdef NEED_COLOR_NAME
 static const char *
@@ -89,7 +90,7 @@ color_name(int color)
     const char *result = 0;
 
     if (color >= (int) SIZEOF(the_color_names)) {
-	_nc_SPRINTF(temp, _nc_SLIMIT(sizeof(result)) "%d", color);
+	_nc_SPRINTF(temp, _nc_SLIMIT(sizeof(temp)) "%d", color);
 	result = temp;
     } else if (color < 0) {
 	result = "default";
