@@ -1,5 +1,6 @@
 /****************************************************************************
- * Copyright (c) 2007-2013,2017 Free Software Foundation, Inc.              *
+ * Copyright 2019,2020 Thomas E. Dickey                                     *
+ * Copyright 2007-2013,2017 Free Software Foundation, Inc.                  *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -29,7 +30,7 @@
 /*
  * Author: Thomas E. Dickey - 2007
  *
- * $Id: dots_mvcur.c,v 1.19 2017/11/24 19:26:31 tom Exp $
+ * $Id: dots_mvcur.c,v 1.22 2020/02/02 23:34:34 tom Exp $
  *
  * A simple demo of the terminfo interface, and mvcur.
  */
@@ -138,7 +139,7 @@ main(int argc GCC_UNUSED,
      char *argv[]GCC_UNUSED)
 {
     int x0 = 1, y0 = 1;
-    int x, y, z, p;
+    int ch;
     double r;
     double c;
     SCREEN *sp;
@@ -146,11 +147,16 @@ main(int argc GCC_UNUSED,
     int f_option = 0;
     int m_option = 2;
     int s_option = 1;
+    size_t need;
+    char *my_env;
 
-    while ((x = getopt(argc, argv, "T:efm:s:")) != -1) {
-	switch (x) {
+    while ((ch = getopt(argc, argv, "T:efm:s:")) != -1) {
+	switch (ch) {
 	case 'T':
-	    putenv(strcat(strcpy(malloc(6 + strlen(optarg)), "TERM="), optarg));
+	    need = 6 + strlen(optarg);
+	    my_env = malloc(need);
+	    _nc_SPRINTF(my_env, _nc_SLIMIT(need) "TERM=%s", optarg);
+	    putenv(my_env);
 	    break;
 #if HAVE_USE_ENV
 	case 'e':
@@ -200,9 +206,9 @@ main(int argc GCC_UNUSED,
     started = time((time_t *) 0);
 
     while (!interrupted) {
-	x = (int) (c * ranf()) + m_option;
-	y = (int) (r * ranf()) + m_option;
-	p = (ranf() > 0.9) ? '*' : ' ';
+	int x = (int) (c * ranf()) + m_option;
+	int y = (int) (r * ranf()) + m_option;
+	int p = (ranf() > 0.9) ? '*' : ' ';
 
 	if (mvcur(y0, x0, y, x) != ERR) {
 	    x0 = x;
@@ -210,7 +216,7 @@ main(int argc GCC_UNUSED,
 	}
 
 	if (my_colors > 0) {
-	    z = (int) (ranf() * my_colors);
+	    int z = (int) (ranf() * my_colors);
 	    if (ranf() > 0.01) {
 		tputs(tparm2(set_a_foreground, z), 1, outc);
 	    } else {
