@@ -1,5 +1,6 @@
 /****************************************************************************
- * Copyright (c) 2006-2017,2019 Free Software Foundation, Inc.              *
+ * Copyright 2019,2020 Thomas E. Dickey                                     *
+ * Copyright 2006-2014,2017 Free Software Foundation, Inc.                  *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -26,7 +27,7 @@
  * authorization.                                                           *
  ****************************************************************************/
 /*
- * $Id: echochar.c,v 1.19 2019/08/24 23:11:01 tom Exp $
+ * $Id: echochar.c,v 1.21 2020/02/02 23:34:34 tom Exp $
  *
  * Demonstrate the echochar function (compare to dots.c).
  * Thomas Dickey - 2006/11/4
@@ -43,7 +44,7 @@ static time_t started;
 static void
 cleanup(void)
 {
-    exit_curses();
+    stop_curses();
 
     printf("\n\n%ld total cells, rate %.2f/sec\n",
 	   total_chars,
