@@ -1,5 +1,6 @@
 /****************************************************************************
- * Copyright (c) 1998-2014,2017 Free Software Foundation, Inc.              *
+ * Copyright 2019,2020 Thomas E. Dickey                                     *
+ * Copyright 1998-2014,2017 Free Software Foundation, Inc.                  *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -41,7 +42,7 @@
  *
  *	Date: 05.Nov.90
  *
- * $Id: hanoi.c,v 1.39 2017/09/09 00:19:24 tom Exp $
+ * $Id: hanoi.c,v 1.41 2020/02/02 23:34:34 tom Exp $
  */
 
 #include <test.priv.h>
@@ -354,6 +355,6 @@ main(int argc, char **argv)
 	    }
 	}
     }
-    exit_curses();
+    stop_curses();
     ExitProgram(EXIT_SUCCESS);
 }
